@@ -8,10 +8,10 @@ class OTPMiddleware(object):
     :class:`~django.contrib.auth.middleware.AuthenticationMiddleware` and
     performs an analagous function. Just as AuthenticationMiddleware populates
     ``request.user`` based on session data, OTPMiddleware populates
-    ``request.user.otp_device`` to the :class:`~django_otp.models.Device` object
-    that has verified the user, or ``None`` if the user has not been verified.
-    As a convenience, this also installs ``user.is_verified()``, which returns
-    ``True`` if ``user.otp_device`` is not ``None``.
+    ``request.user.otp_device`` to the :class:`~django_otp.models.Device`
+    object that has verified the user, or ``None`` if the user has not been
+    verified.  As a convenience, this also installs ``user.is_verified()``,
+    which returns ``True`` if ``user.otp_device`` is not ``None``.
     """
     def process_request(self, request):
         user = getattr(request, 'user', None)
@@ -26,7 +26,7 @@ class OTPMiddleware(object):
             return None
 
         device_id = request.session.get(DEVICE_ID_SESSION_KEY)
-        device = Device.objects.from_persistent_id(device_id) if device_id else None
+        device = Device.from_persistent_id(device_id) if device_id else None
 
         if (device is not None) and (device.user_id != user.id):
             device = None
