@@ -11,7 +11,7 @@ class HOTPTest(TestCase):
         try:
             alice = self.create_user('alice', 'password')
         except IntegrityError:
-            self.skipTest(u"Unable to create test user.")
+            self.skipTest("Unable to create test user.")
         else:
             self.device = alice.hotpdevice_set.create(
                 key='d2e8a68036f68960b1c30532bb6c56da5934d879', digits=6,
@@ -21,23 +21,23 @@ class HOTPTest(TestCase):
     def test_normal(self):
         ok = self.device.verify_token(self.tokens[0])
 
-        self.assert_(ok)
+        self.assertTrue(ok)
         self.assertEqual(self.device.counter, 1)
 
     def test_normal_drift(self):
         ok = self.device.verify_token(self.tokens[1])
 
-        self.assert_(ok)
+        self.assertTrue(ok)
         self.assertEqual(self.device.counter, 2)
 
     def test_excessive_drift(self):
         ok = self.device.verify_token(self.tokens[2])
 
-        self.assert_(not ok)
+        self.assertTrue(not ok)
         self.assertEqual(self.device.counter, 0)
 
     def test_bad_value(self):
         ok = self.device.verify_token(123456)
 
-        self.assert_(not ok)
+        self.assertTrue(not ok)
         self.assertEqual(self.device.counter, 0)
